pub struct Cache { /* private fields */ }Expand description
This is the CACHE Controller
Implementations
Sourceimpl Cache
impl Cache
pub const unsafe fn from_ptr(ptr: *mut ()) -> Self
pub const fn as_ptr(&self) -> *mut ()
Sourcepub const fn spi_bank(self) -> Reg<u32, RW>
pub const fn spi_bank(self) -> Reg<u32, RW>
CSPI Bank. This is ORed into the access address from the processor to create the address sent over to the SPI Flash.
Sourcepub const fn tag_vldt_addr(self) -> Reg<u32, RW>
pub const fn tag_vldt_addr(self) -> Reg<u32, RW>
Tag Force Address. This is the address that will be stored in the Tag Line and accessed over SPI if a Tag Force is issued. This address is still used in conjunction with the Cache SPI Bank.This is meant to be an address from the processors perspective. 4 Byte Boundary aligned
Sourcepub const fn hit_hi(self) -> Reg<u32, RW>
pub const fn hit_hi(self) -> Reg<u32, RW>
Hit count Hi. Stores the Hit Count [63:32] of the Cache
Sourcepub const fn hit_low(self) -> Reg<u32, RW>
pub const fn hit_low(self) -> Reg<u32, RW>
Hit count low. Stores the Hit Count [31:0] of the Cache
Sourcepub const fn miss_hi(self) -> Reg<u32, RW>
pub const fn miss_hi(self) -> Reg<u32, RW>
Miss count Hi. Stores the Miss Count [63:32] of the Cache
Sourcepub const fn miss_low(self) -> Reg<u32, RW>
pub const fn miss_low(self) -> Reg<u32, RW>
Miss count low. Stores the Miss Count [31:0] of the Cache
Sourcepub const fn fill_hi(self) -> Reg<u32, RW>
pub const fn fill_hi(self) -> Reg<u32, RW>
Fill count Hi. Stores the Fill Count [63:32] of the Cache
Sourcepub const fn fill_low(self) -> Reg<u32, RW>
pub const fn fill_low(self) -> Reg<u32, RW>
Fill count low. Stores the Fill Count [31:0] of the Cache
Sourcepub const fn tag_lock0(self) -> Reg<u32, RW>
pub const fn tag_lock0(self) -> Reg<u32, RW>
Tag Lock0. 0: Tag is not Locked. 1: Tag is Locked.
Sourcepub const fn tag_lock1(self) -> Reg<u32, RW>
pub const fn tag_lock1(self) -> Reg<u32, RW>
Tag Lock1. 0: Tag is not Locked. 1: Tag is Locked.
Sourcepub const fn tag_valid0(self) -> Reg<u32, R>
pub const fn tag_valid0(self) -> Reg<u32, R>
Tag Valid0. Tells Line has valid data in the cache. 0: Line is empty. 1: Line is full.
Sourcepub const fn tag_valid1(self) -> Reg<u32, R>
pub const fn tag_valid1(self) -> Reg<u32, R>
Tag Valid1. Tells Line has valid data in the cache. 0: Line is empty. 1: Line is full.